import Vue from 'vue'
import VueRouter from 'vue-router'
import axios from 'axios'
import Mint from 'mint-ui'
import wx from 'weixin-js-sdk'
import qs from 'qs'

import routes from './router/router'
import store from './store/'
import ajax from './config/ajax'
import {routerMode,imgBaseUrl,baseUrl} from './config/env'
import {DOWNLOAD_APP,OPEN_APP,Useragent} from './config/downConfig'
import './config/wxShareConfig'
import './config/rem'
import './config/ajax'

import './style/base.less'
import 'mint-ui/lib/style.css'; 

Vue.prototype.$axios = axios;  // axios 不支持Vue.use(axios)写法
Vue.use(VueRouter)
Vue.use(Mint)

//全局基础域名
global.baseUrl=baseUrl;
global.imgBaseUrl=imgBaseUrl;

global.DOWNLOAD_APP=DOWNLOAD_APP;
global.OPEN_APP=OPEN_APP;
global.Useragent=Useragent;


//设置拦截器,axios降级为简单请求, 避免发送options请求
axios.interceptors.request.use(function (config) {
    config.headers['Content-Type'] = 'application/x-www-form-urlencoded'
    if(config.method === 'post') {
        config.data = qs.stringify( {
            ...config.data
        })
    } 
    return config;
  }, function (error) {
    loadinginstace.close()
    return Promise.reject(error);
  })


//注册全局指令
Vue.directive('title', {
  update: function (el, binding) {
	 document.getElementById('title').innerText = binding.value;
  }
})

//实例化路由
const router = new VueRouter({
	mode: 'history',
	base: '/mobile/',
	routes
})

router.beforeEach((to, from, next) => {
  if (to.matched.length ===0) {    //如果未匹配到路由
    from.name ? next({ name:from.name }) : next('/error');   //如果上级也未匹配到路由则跳转登录页面，如果上级能匹配到则转上级路由
  } else {
    next();   //如果匹配到正确跳转
  }
});


//实例化vue
new Vue({
	router,
	store,
}).$mount('#app')